@@ -1,5 +1,7 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -15,27 +17,33 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
-#pragma once
 #ifndef GAMESTATETITLE_H
 #define GAMESTATETITLE_H
 
 #include "GameState.h"
 #include "Widget.h"
 
+class MenuMovementType;
 class WidgetButton;
 class WidgetLabel;
 
 class GameStateTitle : public GameState {
 private:
-	SDL_Surface *logo;
+	void refreshWidgets();
+
+	Sprite *logo;
 	WidgetButton *button_play;
 	WidgetButton *button_exit;
 	WidgetButton *button_cfg;
 	WidgetButton *button_credits;
 	WidgetLabel *label_version;
+	MenuMovementType *menu_movement_type;
 
 	TabList tablist;
 
+	Point pos_logo;
+	int align_logo;
+
 public:
 	GameStateTitle();
 	~GameStateTitle();
