@@ -1,5 +1,6 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2012-2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -21,8 +22,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * Holds the collection of hazards (active attacks, spells, etc) and handles group operations
  */
 
-
-#pragma once
 #ifndef HAZARD_MANAGER_H
 #define HAZARD_MANAGER_H
 
@@ -30,20 +29,23 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #include "Utils.h"
 
 class Avatar;
+class Entity;
 class Hazard;
 
 class HazardManager {
+private:
+	void hitEntity(size_t index, const bool hit);
+
 public:
 	HazardManager();
 	~HazardManager();
 	void logic();
-	void expire(int index);
 	void checkNewHazards();
 	void handleNewMap();
 	void addRenders(std::vector<Renderable> &r, std::vector<Renderable> &r_dead);
 
 	std::vector<Hazard*> h;
-	Enemy* last_enemy;
+	Entity* last_enemy;
 };
 
 #endif
