@@ -1,5 +1,6 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -19,8 +20,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class ItemStorage
  */
 
-
-#pragma once
 #ifndef ITEM_STORAGE_H
 #define ITEM_STORAGE_H
 
@@ -34,27 +33,29 @@ protected:
 	int slot_number;
 
 public:
-	void init(int _slot_number);
+	static const int NO_SLOT = -1;
+	ItemStorage();
 	~ItemStorage();
+	void init(int _slot_number);
 
 	ItemStack & operator [] (int slot);
 
-	void setItems(std::string s);
-	void setQuantities(std::string s);
+	void setItems(const std::string& s);
+	void setQuantities(const std::string& s);
 	int getSlotNumber();
 	std::string getItems();
 	std::string getQuantities();
-	void add(ItemStack stack, int slot = -1);
-	void substract(int slot, int quantity = 1);
-	bool remove(int item);
+	ItemStack add(ItemStack stack, int slot);
+	void subtract(int slot, int quantity);
+	bool remove(ItemID item, int quantity);
 	void sort();
 	void clear();
 	void clean();
+	bool empty();
 
 	bool full(ItemStack stack);
-	bool full(int item);
-	int count(int item);
-	bool contain(int item, int quantity = 1);
+	int count(ItemID item);
+	bool contain(ItemID item, int quantity);
 
 	ItemStack * storage;
 };
