@@ -1,6 +1,7 @@
 /*
 Copyright © 2011-2012 kitano
-Copyright © 2013 Henrik Andersson
+Copyright © 2013-2014 Henrik Andersson
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -22,31 +23,41 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * The base class for Menu objects
  */
 
-#pragma once
 #ifndef MENU_H
 #define MENU_H
 
 #include "CommonIncludes.h"
-#include "SoundManager.h"
+#include "Utils.h"
+#include "Widget.h"
 
 class Menu {
-protected:
-
-	SDL_Surface *background;
-
 public:
 	Menu();
 	virtual ~Menu();
 
-	bool visible;
-	SDL_Rect window_area;
-	std::string alignment;
-
+	void setBackground(const std::string& background_image);
+	void setBackgroundDest(const Rect &dest);
+	void setBackgroundClip(const Rect &clip);
 	virtual void align();
-	virtual void render() = 0;
+	virtual void render();
+	virtual void setWindowPos(int x, int y);
 
-	SoundManager::SoundID sfx_open;
-	SoundManager::SoundID sfx_close;
+	bool visible;
+	Rect window_area;
+	int alignment;
+
+	virtual bool parseMenuKey(const std::string &key, const std::string &val);
+
+	SoundID sfx_open;
+	SoundID sfx_close;
+
+	TabList tablist;
+	virtual TabList* getCurrentTabList();
+	virtual void defocusTabLists();
+
+private:
+	Sprite *background;
+	Point window_area_base;
 };
 
 #endif
