@@ -1,5 +1,7 @@
 /*
 Copyright © 2011-2012 Pavel Kirpichyov (Cheshire)
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2014 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -21,32 +23,35 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * Handles the display of the Enemy info of the screen
  */
 
-#pragma once
 #ifndef MENU_ENEMY_H
 #define MENU_ENEMY_H
 
 #include "CommonIncludes.h"
-#include "Settings.h"
+#include "Utils.h"
 #include "WidgetLabel.h"
 
-class Enemy;
+class Entity;
 
 class MenuEnemy : public Menu {
 private:
-	SDL_Surface *bar_hp;
-	SDL_Rect bar_pos;
+	Sprite *bar_hp;
+	Rect bar_pos;
 	LabelInfo text_pos;
 	bool custom_text_pos;
-	SDL_Color color_normal;
+	Point bar_fill_offset;
+	Point bar_fill_size;
+
+	WidgetLabel label_text;
+	WidgetLabel label_stats;
 public:
 	MenuEnemy();
 	~MenuEnemy();
-	Enemy *enemy;
+	Entity *enemy;
 	void loadGraphics();
 	void handleNewMap();
 	void logic();
 	void render();
-	int timeout;
+	Timer timeout;
 };
 
 #endif
