@@ -1,5 +1,7 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2014 Henrik Andersson
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -19,7 +21,6 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class MenuHUDLog
  */
 
-#pragma once
 #ifndef MENU_HUD_LOG_H
 #define MENU_HUD_LOG_H
 
@@ -33,23 +34,32 @@ private:
 
 	std::vector<std::string> log_msg;
 	std::vector<int> msg_age;
-	std::vector<SDL_Surface*> msg_buffer;
+	std::vector<Sprite *> msg_buffer;
 
 	int paragraph_spacing;
 
-	SDL_Color color_normal;
+	Sprite *overlay_bg;
+	bool enable_overlay;
+	bool click_to_dismiss;
+	bool start_at_bottom;
+	bool overlay_at_bottom;
 
 public:
+	enum {
+		MSG_NORMAL = 0,
+		MSG_UNIQUE = 1
+	};
 
 	MenuHUDLog();
 	~MenuHUDLog();
 	void logic();
 	void render();
-	void add(const std::string& s);
+	void add(const std::string& s, int type);
 	void remove(int msg_index);
 	void clear();
+	void renderOverlay();
 
-	Point list_area;
+	bool hide_overlay;
 };
 
 #endif
