@@ -1,5 +1,6 @@
 /*
 Copyright © 2013 Stefan Beller
+Copyright © 2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -15,15 +16,28 @@ You should have received a copy of the GNU General Public License along with
 FLARE.  If not, see http://www.gnu.org/licenses/
 */
 
+#include "Avatar.h"
+#include "CampaignManager.h"
+#include "EnemyGroupManager.h"
+#include "EntityManager.h"
+#include "HazardManager.h"
+#include "LootManager.h"
+#include "MenuActionBar.h"
+#include "MenuPowers.h"
+#include "NPCManager.h"
+#include "PowerManager.h"
 #include "SharedGameResources.h"
 
-MenuPowers *menu_powers = NULL;
-LootManager *loot = NULL;
-EnemyGroupManager *enemyg = NULL;
-PowerManager *powers = NULL;
-MapRenderer *mapr = NULL;
-EnemyManager *enemies = NULL;
-CampaignManager *camp = NULL;
-ItemManager *items = NULL;
 Avatar *pc = NULL;
-
+MenuManager *menu = NULL;
+CampaignManager *camp = NULL;
+EnemyGroupManager *enemyg = NULL;
+EntityManager *entitym = NULL;
+HazardManager *hazards = NULL;
+ItemManager *items = NULL;
+LootManager *loot = NULL;
+MapRenderer *mapr = NULL;
+MenuActionBar *menu_act= NULL;
+MenuPowers *menu_powers = NULL;
+NPCManager *npcs = NULL;
+PowerManager *powers = NULL;
