@@ -1,5 +1,6 @@
 /*
 Copyright © 2013 Stefan Beller
+Copyright © 2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -18,25 +19,35 @@ FLARE.  If not, see http://www.gnu.org/licenses/
 #ifndef SHAREDGAMEOBJECTS_H
 #define SHAREDGAMEOBJECTS_H
 
-#include "LootManager.h"
-#include "MenuPowers.h"
-#include "EnemyGroupManager.h"
-#include "PowerManager.h"
-#include "CampaignManager.h"
-#include "Avatar.h"
-
-extern MenuPowers *menu_powers;
+class Avatar;
+class CampaignManager;
+class EnemyGroupManager;
+class EntityManager;
+class HazardManager;
+class ItemManager;
+class LootManager;
+class MapRenderer;
+class MenuActionBar;
+class MenuManager;
+class MenuPowers;
+class NPCManager;
+class PowerManager;
 
 /* These objects are created in the GameStatePlay constructor and deleted in the GameStatePlay destructor
 *  so can be accessed safely anywhere in between. The objects must not be changed by any other class.
 */
-extern LootManager *loot;
-extern EnemyGroupManager *enemyg;
-extern PowerManager *powers;
-extern MapRenderer *mapr;
-extern EnemyManager *enemies;
-extern CampaignManager *camp;
-extern ItemManager *items;
 extern Avatar *pc;
+extern CampaignManager *camp;
+extern EnemyGroupManager *enemyg;
+extern EntityManager *entitym;
+extern HazardManager *hazards;
+extern ItemManager *items;
+extern LootManager *loot;
+extern MapRenderer *mapr;
+extern MenuActionBar *menu_act;
+extern MenuManager *menu;
+extern MenuPowers *menu_powers;
+extern NPCManager *npcs;
+extern PowerManager *powers;
 
 #endif // SHAREDGAMEOBJECTS_H
