@@ -1,5 +1,6 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
+Copyright © 2015 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -21,21 +22,30 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * Various file system function wrappers. Abstracted here to hide OS-specific implementations
  */
 
-
-#pragma once
 #ifndef UTILS_FILE_SYSTEM_H
 #define UTILS_FILE_SYSTEM_H
 
-#include "CommonIncludes.h"
+#include <string>
 
-bool dirExists(const std::string &path);
-bool pathExists(const std::string &path);
-void createDir(std::string path);
-bool fileExists(std::string filename);
-int getFileList(std::string dir, std::string ext, std::vector<std::string> &files);
-int getDirList(std::string dir, std::vector<std::string> &dirs);
+namespace Filesystem {
+	bool pathExists(const std::string &path);
+	void createDir(const std::string &path);
+	bool fileExists(const std::string &filename);
+	int getFileList(const std::string &dir, const std::string &ext, std::vector<std::string> &files);
+	int getDirList(const std::string &dir, std::vector<std::string> &dirs);
 
+	bool isDirectory(const std::string &path, bool show_error = true);
+
+	bool removeFile(const std::string &file);
+	bool removeDir(const std::string &dir);
+	bool removeDirRecursive(const std::string &dir);
+
+	std::string convertSlashes(const std::string& _path);
+
+	bool renameFile(const std::string &_oldfile, const std::string &_newfile);
+
+	std::string removeTrailingSlash(const std::string& path);
+}
 
-bool isDirectory(const std::string &path);
 
 #endif
