@@ -1,6 +1,8 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
-Copyright © 2012 Justin Jacobs
+Copyright © 2012-2015 Justin Jacobs
+Copyright © 2013 Kurt Rinnert
+Copyright © 2014 Henrik Andersson
 
 This file is part of FLARE.
 
@@ -20,40 +22,50 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class WidgetScrollBar
  */
 
-#pragma once
 #ifndef WIDGET_ScrollBar_H
 #define WIDGET_ScrollBar_H
 
 #include "CommonIncludes.h"
 #include "Widget.h"
 
+class Sprite;
+
 class WidgetScrollBar : public Widget {
 private:
 
-	std::string fileName; // the path to the ScrollBars background image
+	std::string fileName; // the path to the ScrollBar's atlas
 
-	SDL_Surface *scrollbars;
-	Mix_Chunk *click;
+	Sprite *scrollbars;
 
 	int value;
 	int bar_height;
 	int maximum;
+	bool lock_main1;
+	bool dragging;
+
+	Sprite *bg;
+
+	Rect up_to_knob;
+	Rect knob_to_down;
 
 public:
-	WidgetScrollBar(const std::string& _fileName);
+	static const std::string DEFAULT_FILE;
+
+	explicit WidgetScrollBar(const std::string& _fileName);
 	~WidgetScrollBar();
 
 	void loadArt();
 	int checkClick();
-	int checkClick(int x, int y);
+	int checkClickAt(int x, int y);
 	void set();
 	int getValue();
-	void render(SDL_Surface *target = NULL);
+	Rect getBounds();
+	void render();
 	void refresh(int x, int y, int h, int val, int max);
 
-	SDL_Rect pos_up;
-	SDL_Rect pos_down;
-	SDL_Rect pos_knob;
+	Rect pos_up;
+	Rect pos_down;
+	Rect pos_knob;
 	bool pressed_up;
 	bool pressed_down;
 	bool pressed_knob;
