@@ -1,6 +1,8 @@
 /*
 Copyright © 2011-2012 Clint Bellanger
 Copyright © 2012 Stefan Beller
+Copyright © 2013 Kurt Rinnert
+Copyright © 2012-2016 Justin Jacobs
 
 This file is part of FLARE.
 
@@ -20,30 +22,29 @@ FLARE.  If not, see http://www.gnu.org/licenses/
  * class WidgetTooltip
  */
 
-#pragma once
 #ifndef WIDGET_TOOLTIP_H
 #define WIDGET_TOOLTIP_H
 
 #include "CommonIncludes.h"
-#include "SharedResources.h"
 #include "TooltipData.h"
 #include "Utils.h"
 
-extern int TOOLTIP_CONTEXT;
-const int TOOLTIP_NONE = 0;
-const int TOOLTIP_MAP = 1;
-const int TOOLTIP_MENU = 2;
-
 class WidgetTooltip {
-private:
-	int offset; // distance between cursor and tooltip
-	int width; // max width of tooltips (wrap text)
-	int margin; // outer margin between tooltip text and the edge of the tooltip background
 public:
 	WidgetTooltip();
-	Point calcPosition(STYLE style, Point pos, Point size);
-	void render(TooltipData &tip, Point pos, STYLE style, SDL_Surface *target = NULL);
-	void createBuffer(TooltipData &tip);
+	~WidgetTooltip();
+	Point calcPosition(uint8_t style, const Point& pos, const Point& size);
+	void prerender(TooltipData&tip, const Point& pos, uint8_t style);
+	void render(TooltipData &tip, const Point& pos, uint8_t style);
+	bool createBuffer(TooltipData &tip);
+
+	Rect bounds;
+	WidgetTooltip *parent;
+
+private:
+	Image *background;
+	TooltipData data_buf;
+	Sprite* sprite_buf;
 };
 
 #endif
